h1, h2, h3, h4, h5, h6, .h1, .h2, .h3, .h4, .h5, .h6{font-family:Cinzel, Georgia, serif;}h1, h2, h3, h4, h5, h6{text-transform:none;}h1.alt-font, h2.alt-font, h3.alt-font, h4.alt-font, h5.alt-font, h6.alt-font, .h1.alt-font, .h2.alt-font, .h3.alt-font, .h4.alt-font, .h5.alt-font, .h6.alt-font{font-family:Serif;}h1.alt-font, h2.alt-font, h3.alt-font, h4.alt-font, h5.alt-font, h6.alt-font{text-transform:none;}.primary-menu ul li a{font-family:Cinzel, Georgia, serif;font-size:16px;text-transform:uppercase;}.social-menu ul li a{font-family:Cinzel, Georgia, serif;font-size:16px;text-transform:uppercase;}.secondary-menu ul li a{font-family:Cinzel, Georgia, serif;font-size:16px;text-transform:uppercase;}.tertiary-menu ul li a{font-family:Cinzel, Georgia, serif;font-size:16px;text-transform:uppercase;}.footer-center-menu ul li a{font-family:Cinzel, Georgia, serif;font-size:16px;text-transform:uppercase;}body, p, .site-content, .site-footer{font-family:Serif;font-size:14px;line-height:140%;}.site-title{font-family:Cinzel, Georgia, serif;font-size:32px;text-transform:none;margin-top:5px;margin-bottom:20px;line-height:150%;letter-spacing:1px;}.site-title a{text-decoration:none;}.site-title a:hover{text-decoration:none;}.site-title a:focus{text-decoration:none;}.site-branding{margin-left:0px;}.logo-site-title img{width:210px;}